@@ -1,7 +1,7 @@
 /*
  * gtkanyone.h: Show the user tree as a Gtk+ widget
  * David Maze <dmaze@mit.edu>
- * $Id: gtkanyone.h,v 1.14 2001/11/18 23:01:50 dmaze Exp $
+ * $Id: gtkanyone.h,v 1.15 2002/12/22 19:17:25 dmaze Exp $
  */
 
 #ifndef __GTKANYONE_H__
@@ -39,6 +39,9 @@ zgroup *gtk_anyone_group(const GtkAnyone *anyone);
 GString *gtk_anyone_get_filename(const GtkAnyone *anyone);
 void gtk_anyone_update(GtkAnyone *anyone, GtkProgress *progress);
 void gtk_anyone_update_user(GtkAnyone *anyone, zuser *user);
+void gtk_anyone_update_async(GtkAnyone *anyone);
+void gtk_anyone_update_user_async(GtkAnyone *anyone, zuser *user);
+void gtk_anyone_result_async(GtkAnyone *anyone, ZNotice_t *notice);
 void gtk_anyone_construct(GtkAnyone *anyone, zgroup *group, GString *filename);
 
 #endif /* __GTKANYONE_H__ */
