@@ -1,7 +1,7 @@
 /*
  * gznola.c: A GNOME-based xznola
  * David Maze <dmaze@mit.edu>
- * $Id: gznola.c,v 1.13 2002/03/07 02:13:53 dmaze Exp $
+ * $Id: gznola.c,v 1.15 2002/12/22 19:18:55 dmaze Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -11,7 +11,6 @@
 #include "zgroup.h"
 #include "anyone.h"
 #include "gtkanyone.h"
-#include "gtksaneprogressbar.h"
 
 /* Deal with bizarre name conflicts between des.h and GNOME. */
 #undef _
@@ -49,6 +48,7 @@ void read_settings(void);
 void write_settings(void);
 void update_setup(void);
 gint update_timeout(gpointer data);
+gint zephyr_timeout(gpointer data);
 
 /* Definition of the main menu */
 static GnomeUIInfo menu_file[] = {
@@ -112,7 +112,7 @@ struct file_preferences_data
 {
   GtkWidget *zsub_check, *time_check, *time_interval;
 };
-static GtkWidget *app, *progbar;
+static GtkWidget *app;
 static GtkAnyone *anyone;
 
 int main(int argc, char **argv)
@@ -134,8 +134,6 @@ int main(int argc, char **argv)
   app = gnome_app_new(MYNAME, MYNAME);
   gnome_app_create_menus(GNOME_APP(app), menu_main);
   gnome_app_create_toolbar(GNOME_APP(app), toolbar);
-  progbar = gtk_sane_progress_bar_new();
-  gnome_app_set_statusbar(GNOME_APP(app), progbar);
   /* Let the window shrink itself */
   gtk_window_set_policy(GTK_WINDOW(app), TRUE, TRUE, TRUE);
   gtk_widget_show(app);
@@ -148,6 +146,7 @@ int main(int argc, char **argv)
 
   znol_update();
   update_setup();
+  gtk_timeout_add(1000, zephyr_timeout, NULL);
   
   gtk_main();
   return 0;
@@ -206,7 +205,7 @@ void znol_reopen(void)
 void znol_update(void)
 {
   if (anyone)
-    gtk_anyone_update(anyone, GTK_PROGRESS(progbar));
+    gtk_anyone_update_async(anyone);
 }
 
 /**
@@ -433,7 +432,7 @@ void help_about(gpointer data)
   static const char *authors[] = { "David Maze <dmaze@mit.edu>", NULL };
   
   widget = gnome_about_new(MYNAME, VERSION,
-			   "(C) 1999-2000, David Z. Maze", authors,
+			   "(C) 1999-2003, David Z. Maze", authors,
 			   "Displays a heirarchical tree of users "
 			   "visible over Zephyr.\n"
 			   "Project home page: "
@@ -481,3 +480,22 @@ gint update_timeout(gpointer data)
   znol_update();
   return TRUE;
 }
+
+gint zephyr_timeout(gpointer data)
+{
+  while (ZPending())
+  {
+    int cresult;
+    ZNotice_t notice;
+    
+    cresult = ZReceiveNotice(&notice, NULL);
+    if (cresult != ZERR_NONE)
+    {
+      g_error("While receiving notice: %s", error_message(cresult));
+      break;
+    }
+    gtk_anyone_result_async(anyone, &notice);
+    ZFreeNotice(&notice);
+  }
+  return TRUE;
+}
